==> QHangups-1.7.1.tar.gz: QHangups-1.7.1/qhangups/languages/qhangups_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="cs_CZ" sourcelanguage="">
<context>
    <name>QHangupsBrowser</name>
    <message>
        <location filename="ui_qhangupsbrowser.py" line="27"/>
        <source>QHangups - Browser</source>
        <translation>QHangups - Prohlížeč</translation>
    </message>
</context>
<context>
    <name>QHangupsConversationWidget</name>
    <message>
        <location filename="conversationwidget.py" line="254"/>
        <source>QHangups - Warning</source>
        <translation>QHangups - Varování</translation>
    </message>
    <message>
        <location filename="conversationwidget.py" line="254"/>
        <source>Failed to send message!</source>
        <translation>Zprávu se nepodařilo odeslat!</translation>
    </message>
    <message>
        <location filename="ui_qhangupsconversationwidget.py" line="53"/>
        <source>QHangups - Conversation</source>
        <translation>QHangups - Konverzace</translation>
    </message>
    <message>
        <location filename="ui_qhangupsconversationwidget.py" line="54"/>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <location filename="ui_qhangupsconversationwidget.py" line="55"/>
        <source>Ctrl+Return</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QHangupsConversations</name>
    <message>
        <location filename="ui_qhangupsconversations.py" line="40"/>
        <source>QHangups - Conversations</source>
        <translation>QHangups - Konverzace</translation>
    </message>
</context>
<context>
    <name>QHangupsConversationsList</name>
    <message>
        <location filename="ui_qhangupsconversationslist.py" line="37"/>
        <source>QHangups</source>
        <translation></translation>
    </message>
    <message>
        <location filename="conversationslist.py" line="79"/>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <location filename="conversationslist.py" line="65"/>
        <source>Reconnecting...</source>
        <translation>Opakuji připojení...</translation>
    </message>
    <message>
        <location filename="conversationslist.py" line="73"/>
        <source>Connecting...</source>
        <translation>Připojuji se...</translation>
    </message>
</context>
<context>
    <name>QHangupsMainWidget</name>
    <message>
        <location filename="__main__.py" line="119"/>
        <source>&amp;Connect</source>
        <translation>&amp;Připojit</translation>
    </message>
    <message>
        <location filename="__main__.py" line="120"/>
        <source>&amp;Disconnect</source>
        <translation>&amp;Odpojit</translation>
    </message>
    <message>
        <location filename="__main__.py" line="121"/>
        <source>S&amp;ettings ...</source>
        <translation>Na&amp;stavení ...</translation>
    </message>
    <message>
        <location filename="__main__.py" line="122"/>
        <source>A&amp;bout ...</source>
        <translation>O p&amp;rogramu ...</translation>
    </message>
    <message>
        <location filename="__main__.py" line="123"/>
        <source>&amp;Quit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <location filename="__main__.py" line="131"/>
        <source>QHangups - Warning</source>
        <translation>QHangups - Varování</translation>
    </message>
    <message>
        <location filename="qhangups.py" line="137"/>
        <source>You have been disconnected from Google Hangouts!</source>
        <translation type="obsolete">Byli jste odpojeni od Google Hangouts!</translation>
    </message>
    <message>
        <location filename="__main__.py" line="191"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="__main__.py" line="191"/>
        <source>QHangups {}</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__main__.py" line="249"/>
        <source>QHangups - Quit</source>
        <translation>QHangups - Ukončení</translation>
    </message>
    <message>
        <location filename="__main__.py" line="249"/>
        <source>You are still connected to Google Hangouts. Do you really want to quit QHangups?</source>
        <translation>Jste stále připojeni ke Google Hangouts. Chcete opravdu ukončit QHangups?</translation>
    </message>
    <message>
        <location filename="__main__.py" line="131"/>
        <source>Google login failed!</source>
        <translation>Přihlášení k serveru Google selhalo!</translation>
    </message>
    <message>
        <location filename="__main__.py" line="136"/>
        <source>QHangups - Password</source>
        <translation type="obsolete">QHangups - Heslo</translation>
    </message>
    <message>
        <location filename="__main__.py" line="136"/>
        <source>Password:</source>
        <translation type="obsolete">Heslo:</translation>
    </message>
    <message>
        <location filename="__main__.py" line="138"/>
        <source>QHangups - Authorization</source>
        <translation>QHangups - Autorizace</translation>
    </message>
    <message>
        <location filename="__main__.py" line="138"/>
        <source>Authorization code:</source>
        <translation>Autorizační kód:</translation>
    </message>
</context>
<context>
    <name>QHangupsSettings</name>
    <message>
        <location filename="ui_qhangupssettings.py" line="51"/>
        <source>QHangups - Settings</source>
        <translation>QHangups - Nastavení</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="55"/>
        <source>Language:</source>
        <translation>Jazyk:</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="52"/>
        <source>Send client active notifications</source>
        <translation>Odesílat notifikace o aktivitě klienta</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="53"/>
        <source>Send read state notifications</source>
        <translation>Odesílat notifikace o přečtení zpráv</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="54"/>
        <source>Press Enter to send message (default is Ctrl+Enter)</source>
        <translation>Tlačítko Enter odešle zprávu (výchozí zkratka je Ctrl+Enter)</translation>
    </message>
</context>
</TS>

==> QHangups-1.8.1.tar.gz: QHangups-1.8.1/qhangups/languages/qhangups_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="cs_CZ" sourcelanguage="">
<context>
    <name>CredentialsPrompt</name>
    <message>
        <location filename="__main__.py" line="45"/>
        <source>QHangups - Email</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__main__.py" line="45"/>
        <source>Email:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__main__.py" line="54"/>
        <source>QHangups - Password</source>
        <translation>QHangups - Heslo</translation>
    </message>
    <message>
        <location filename="__main__.py" line="54"/>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <location filename="__main__.py" line="63"/>
        <source>QHangups - Verification code</source>
        <translation>QHangups - Ověřovací kód</translation>
    </message>
    <message>
        <location filename="__main__.py" line="63"/>
        <source>Verification code:</source>
        <translation>Ověřovací kód:</translation>
    </message>
</context>
<context>
    <name>QHangupsBrowser</name>
    <message>
        <location filename="ui_qhangupsbrowser.py" line="27"/>
        <source>QHangups - Browser</source>
        <translation>QHangups - Prohlížeč</translation>
    </message>
</context>
<context>
    <name>QHangupsConversationWidget</name>
    <message>
        <location filename="conversationwidget.py" line="263"/>
        <source>QHangups - Warning</source>
        <translation>QHangups - Varování</translation>
    </message>
    <message>
        <location filename="conversationwidget.py" line="263"/>
        <source>Failed to send message!</source>
        <translation>Zprávu se nepodařilo odeslat!</translation>
    </message>
    <message>
        <location filename="ui_qhangupsconversationwidget.py" line="68"/>
        <source>QHangups - Conversation</source>
        <translation>QHangups - Konverzace</translation>
    </message>
    <message>
        <location filename="ui_qhangupsconversationwidget.py" line="69"/>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <location filename="ui_qhangupsconversationwidget.py" line="70"/>
        <source>Ctrl+Return</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QHangupsConversations</name>
    <message>
        <location filename="ui_qhangupsconversations.py" line="40"/>
        <source>QHangups - Conversations</source>
        <translation>QHangups - Konverzace</translation>
    </message>
</context>
<context>
    <name>QHangupsConversationsList</name>
    <message>
        <location filename="ui_qhangupsconversationslist.py" line="37"/>
        <source>QHangups</source>
        <translation></translation>
    </message>
    <message>
        <location filename="conversationslist.py" line="83"/>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <location filename="conversationslist.py" line="69"/>
        <source>Reconnecting...</source>
        <translation>Opakuji připojení...</translation>
    </message>
    <message>
        <location filename="conversationslist.py" line="77"/>
        <source>Connecting...</source>
        <translation>Připojuji se...</translation>
    </message>
</context>
<context>
    <name>QHangupsMainWidget</name>
    <message>
        <location filename="__main__.py" line="158"/>
        <source>&amp;Connect</source>
        <translation>&amp;Připojit</translation>
    </message>
    <message>
        <location filename="__main__.py" line="159"/>
        <source>&amp;Disconnect</source>
        <translation>&amp;Odpojit</translation>
    </message>
    <message>
        <location filename="__main__.py" line="160"/>
        <source>S&amp;ettings ...</source>
        <translation>Na&amp;stavení ...</translation>
    </message>
    <message>
        <location filename="__main__.py" line="161"/>
        <source>A&amp;bout ...</source>
        <translation>O p&amp;rogramu ...</translation>
    </message>
    <message>
        <location filename="__main__.py" line="162"/>
        <source>&amp;Quit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <location filename="__main__.py" line="171"/>
        <source>QHangups - Warning</source>
        <translation>QHangups - Varování</translation>
    </message>
    <message>
        <location filename="qhangups.py" line="137"/>
        <source>You have been disconnected from Google Hangouts!</source>
        <translation type="obsolete">Byli jste odpojeni od Google Hangouts!</translation>
    </message>
    <message>
        <location filename="__main__.py" line="231"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="__main__.py" line="231"/>
        <source>QHangups {}</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__main__.py" line="289"/>
        <source>QHangups - Quit</source>
        <translation>QHangups - Ukončení</translation>
    </message>
    <message>
        <location filename="__main__.py" line="289"/>
        <source>You are still connected to Google Hangouts. Do you really want to quit QHangups?</source>
        <translation>Jste stále připojeni ke Google Hangouts. Chcete opravdu ukončit QHangups?</translation>
    </message>
    <message>
        <location filename="__main__.py" line="171"/>
        <source>Google login failed!</source>
        <translation>Přihlášení k serveru Google selhalo!</translation>
    </message>
    <message>
        <location filename="__main__.py" line="136"/>
        <source>QHangups - Password</source>
        <translation type="obsolete">QHangups - Heslo</translation>
    </message>
    <message>
        <location filename="__main__.py" line="136"/>
        <source>Password:</source>
        <translation type="obsolete">Heslo:</translation>
    </message>
    <message>
        <location filename="__main__.py" line="178"/>
        <source>QHangups - Authorization</source>
        <translation>QHangups - Autorizace</translation>
    </message>
    <message>
        <location filename="__main__.py" line="178"/>
        <source>Authorization code:</source>
        <translation>Autorizační kód:</translation>
    </message>
</context>
<context>
    <name>QHangupsSettings</name>
    <message>
        <location filename="ui_qhangupssettings.py" line="57"/>
        <source>QHangups - Settings</source>
        <translation>QHangups - Nastavení</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="60"/>
        <source>Language:</source>
        <translation>Jazyk:</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="61"/>
        <source>Send client active notifications</source>
        <translation>Odesílat notifikace o aktivitě klienta</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="58"/>
        <source>Send read state notifications</source>
        <translation>Odesílat notifikace o přečtení zpráv</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="62"/>
        <source>Press Enter to send message (default is Ctrl+Enter)</source>
        <translation>Tlačítko Enter odešle zprávu (výchozí zkratka je Ctrl+Enter)</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="59"/>
        <source>Connection events in feed</source>
        <translation>Zobrazovat události o připojení v konverzaci</translation>
    </message>
    <message>
        <location filename="ui_qhangupssettings.py" line="63"/>
        <source>Auto-connect</source>
        <translation>Automatické připojení</translation>
    </message>
</context>
<context>
    <name>self.parent</name>
    <message>
        <location filename="__main__.py" line="56"/>
        <source>QHangups - Password</source>
        <translation type="obsolete">QHangups - Heslo</translation>
    </message>
    <message>
        <location filename="__main__.py" line="56"/>
        <source>Password:</source>
        <translation type="obsolete">Heslo:</translation>
    </message>
    <message>
        <location filename="__main__.py" line="67"/>
        <source>QHangups - Verification code</source>
        <translation type="obsolete">QHangups - Ověřovací kód</translation>
    </message>
    <message>
        <location filename="__main__.py" line="67"/>
        <source>Verification code:</source>
        <translation type="obsolete">Ověřovací kód:</translation>
    </message>
</context>
</TS>
